@@ -137,7 +137,10 @@ main(int argc,
 
   auto const home_dir = g_get_home_dir();
   if (home_dir == nullptr || chdir(home_dir) < 0)
-   (void) chdir("/");
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-result"
+    chdir("/");
+#pragma GCC diagnostic pop
 
   g_set_prgname("gnome-terminal-preferences");
   g_set_application_name(_("Terminal Preferences"));
